



# Important Photon OS Security Update

## Summary

Advisory Id     : PHSA-2017-0010

Type            : Security

Severity        : ['Important', 'Moderate']

Issue date      : 2017-02-02

Affected Release: 1.0

## Details

Updates of ['linux', 'linux-esx', 'perl'] packages of Photon OS have been released.
## Affected Packages

### Important

perl - ['[CVE-2016-1238](https://nvd.nist.gov/vuln/detail/CVE-2016-1238)']

### Moderate

linux - ['[CVE-2016-9178](https://nvd.nist.gov/vuln/detail/CVE-2016-9178)']

linux-esx - ['[CVE-2016-9178](https://nvd.nist.gov/vuln/detail/CVE-2016-9178)']

## Solution

Update the affected packages (tdnf update package)
